# -*- coding: utf-8 -*-
"""Performing matrix multiplication and finding Eigen vectors and Eigen values  using Tensor Flow

Automatically generated by Colab.

Original file is located at
    https://colab.research.google.com/drive/1Cef6TY4UreI4bjAEovxQ6zb6GHHvCzAr
"""

import tensorflow as tf

A = tf.constant([[3, 2], [2, 3]], dtype=tf.float32)
B = tf.constant([[1, 2], [3, 4]], dtype=tf.float32)
C = tf.matmul(A, B)

eigen_values, eigen_vectors = tf.linalg.eigh(A)

print("Matrix A:\n", A.numpy())
print("\nMatrix B:\n", B.numpy())
print("\nMatrix Multiplication (A * B):\n", C.numpy())
print("\nEigenvalues of A:\n", eigen_values.numpy())
print("\nEigenvectors of A:\n", eigen_vectors.numpy())